==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/ko.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "라이트 박스 GALLARY 매개 변수 관리");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "갤러리 관리");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "전체 크기 이미지의 폭");
define('MANAGE_GALLERY_FULL_HEIGHT', "전체 크기 이미지 높이");
define('MANAGE_GALLERY_THUMB_WIDTH', "썸네일 이미지의 폭");
define('MANAGE_GALLERY_THUMB_HEIGHT', "썸네일 이미지 높이");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "엄지 손가락의 가로 세로 비율을 유지");
define('MANAGE_GALLERY_SHOW_TITLES', "보기 제목");
define('MANAGE_GALLERY_DISABLE_SORT', "안 정렬");
define('MANAGE_GALLERY_DELETE_IMAGE', "이미지 삭제");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "주문 정렬 저장");
define('MANAGE_GALLERY_PUBLISH_MSG', "게시 &#39;업데이트&#39;를 클릭 <br /> 업로드 한 이미지.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "모든 이미지는 크기가 조정되었으며, 설정이 저장되었습니다.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "오류 이미지 크기를 조정하거나 설정을 저장 있었다.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "이미지 (들) 업로드되었습니다.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "이미지 (들)을 업로드하는 중에 오류가 발생했습니다.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "업로드하려는 파일은 이미지가 아닙니다.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "업로드하려는 파일이 너무 큽니다.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "제목은 저장되었습니다.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "당신은 당신이 이미지를 삭제 하시겠습니까");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "이미지가 삭제되었습니다.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "이미지를 삭제하는 중에 오류가 발생했습니다.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "매개 변수를 저장 및 이미지 크기를 조정, 잠시 기다려주세요 ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "업로드, 잠시 기다려주세요 ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "정렬 순서가 저장되지 않았습니다. 당신은 정렬 순서를 저장 하시겠습니까?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "이미지 정렬 순서가 저장되었습니다.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "이미지 정렬을 저장하는 중에 오류가 발생했습니다.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/ko.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "라이트 박스 GALLARY 매개 변수 관리");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "갤러리 관리");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "전체 크기 이미지의 폭");
define('MANAGE_GALLERY_FULL_HEIGHT', "전체 크기 이미지 높이");
define('MANAGE_GALLERY_THUMB_WIDTH', "썸네일 이미지의 폭");
define('MANAGE_GALLERY_THUMB_HEIGHT', "썸네일 이미지 높이");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "엄지 손가락의 가로 세로 비율을 유지");
define('MANAGE_GALLERY_SHOW_TITLES', "보기 제목");
define('MANAGE_GALLERY_DISABLE_SORT', "안 정렬");
define('MANAGE_GALLERY_DELETE_IMAGE', "이미지 삭제");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "주문 정렬 저장");
define('MANAGE_GALLERY_PUBLISH_MSG', "게시 &#39;업데이트&#39;를 클릭 <br /> 업로드 한 이미지.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "모든 이미지는 크기가 조정되었으며, 설정이 저장되었습니다.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "오류 이미지 크기를 조정하거나 설정을 저장 있었다.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "이미지 (들) 업로드되었습니다.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "이미지 (들)을 업로드하는 중에 오류가 발생했습니다.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "업로드하려는 파일은 이미지가 아닙니다.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "업로드하려는 파일이 너무 큽니다.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "제목은 저장되었습니다.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "당신은 당신이 이미지를 삭제 하시겠습니까");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "이미지가 삭제되었습니다.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "이미지를 삭제하는 중에 오류가 발생했습니다.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "매개 변수를 저장 및 이미지 크기를 조정, 잠시 기다려주세요 ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "업로드, 잠시 기다려주세요 ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "정렬 순서가 저장되지 않았습니다. 당신은 정렬 순서를 저장 하시겠습니까?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "이미지 정렬 순서가 저장되었습니다.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "이미지 정렬을 저장하는 중에 오류가 발생했습니다.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "업로드하려는 파일이 &#39;upload_max_filesize&#39;또는 &#39;post_max_size&#39;PHP 설정보다 큽니다. 이 한계를 늘리려면 시스템 관리자에게 문의하십시오.");
?>
